Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2474)

Unified Diff: ash/display/window_tree_host_manager_unittest.cc

Issue 2215223004: mash: Migrate ShelfLayoutManager ScreenUtil usage to ash common types. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Cleanup. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/display/window_tree_host_manager_unittest.cc
diff --git a/ash/display/window_tree_host_manager_unittest.cc b/ash/display/window_tree_host_manager_unittest.cc
index a754e19e3bf70a61f2be0b911d77cda9dc8967df..6e25e341edac159f157ca2ed2cc3f5cd15b3b299 100644
--- a/ash/display/window_tree_host_manager_unittest.cc
+++ b/ash/display/window_tree_host_manager_unittest.cc
@@ -6,11 +6,13 @@
#include <memory>
+#include "ash/aura/wm_window_aura.h"
#include "ash/common/ash_switches.h"
#include "ash/common/display/display_info.h"
#include "ash/common/material_design/material_design_controller.h"
#include "ash/common/wm/window_state.h"
#include "ash/common/wm/wm_event.h"
+#include "ash/common/wm/wm_screen_util.h"
#include "ash/display/display_layout_store.h"
#include "ash/display/display_manager.h"
#include "ash/display/display_util.h"
@@ -1297,7 +1299,8 @@ class RootWindowTestObserver : public aura::WindowObserver {
void OnWindowBoundsChanged(aura::Window* window,
const gfx::Rect& old_bounds,
const gfx::Rect& new_bounds) override {
- shelf_display_bounds_ = ScreenUtil::GetShelfDisplayBoundsInRoot(window);
+ shelf_display_bounds_ =
+ wm::GetShelfDisplayBoundsForWindow(WmWindowAura::Get(window));
}
const gfx::Rect& shelf_display_bounds() const {
@@ -1312,8 +1315,8 @@ class RootWindowTestObserver : public aura::WindowObserver {
} // names
// Make sure that GetShelfDisplayBoundsInRoot returns the correct bounds
// when primary display gets replaced in a following scenario.
// 1) Two displays connected: a) b)
// 2) both are disconnected and new one with the same size as b) is connected
// in one configuration event.
@@ -1312,8 +1315,8 @@ class RootWindowTestObserver : public aura::WindowObserver {
} // names
-// Make sure that GetShelfDisplayBoundsInRoot returns the correct bounds
-// when primary display gets replaced in a following scenario.
+// Make sure that GetShelfDisplayBoundsForWindow returns the correct bounds
+// when the primary display gets replaced in one of the following scenarios:
// 1) Two displays connected: a) b)
// 2) both are disconnected and new one with the same size as b) is connected

Powered by Google App Engine
This is Rietveld 408576698